from __future__ import absolute_import
from __future__ import print_function


from keras.datasets import mnist
from keras.models import Sequential
from keras.layers.core import Dense, Dropout, Activation
from keras.optimizers import SGD
from keras.utils import np_utils

import matplotlib
import matplotlib.pyplot as plt
import scipy
import numpy as np
np.random.seed(1337)


def plot_load_digit(imageFile):
    # Load freehand drawn image 28x28 pixels
   
    image = scipy.ndimage.imread(imageFile,flatten=True)
    image = (255-image)/255.
    return image

def predictionFormat(image):
    return np.array([image.flatten()])
  
    
def plot_mnist_digit(image):
    """ Plot a single MNIST image."""
    fig = plt.figure()
    ax = fig.add_subplot(1, 1, 1)
    ax.matshow(image, cmap = matplotlib.cm.binary)
    plt.xticks(np.array([]))
    plt.yticks(np.array([]))
    plt.show()

def plot_10_by_10_images(images):
    """ Plot 100 MNIST images in a 10 by 10 table. Note that we crop
    the images so that they appear reasonably close together.  The
    image is post-processed to give the appearance of being continued."""
    fig = plt.figure()
    images = [image[3:25, 3:25] for image in images]
    for x in range(10):
        for y in range(10):
            ax = fig.add_subplot(10, 10, 10*y+x)
            ax.matshow(images[10*y+x], cmap = matplotlib.cm.binary)
            plt.xticks(np.array([]))
            plt.yticks(np.array([]))
    plt.show()




def loadData():
    (X_train, y_train), (X_test, y_test) = mnist.load_data()
    return (X_train, y_train), (X_test, y_test)
    
def reshapeData(nb_classes,X_train, y_train, X_test, y_test):
    X_train = X_train.reshape(60000, 784)
    X_test = X_test.reshape(10000, 784)
    X_train = X_train.astype("float32")
    X_test = X_test.astype("float32")
    X_train /= 255
    X_test /= 255
    y_train = np_utils.to_categorical(y_train, nb_classes)
    y_test = np_utils.to_categorical(y_test, nb_classes)
    return (X_train, y_train), (X_test, y_test)


def learnModel(nb_epoch,nb_classes,X_train, y_train, X_test, y_test):
    #model.add(Dense(1, input_shape=(784,), init='uniform'))
    batch_size = 128
    nb_classes = 10
    model = Sequential()
    model.add(Dense(1, input_shape=(784,), init='uniform'))
    model.add(Activation('sigmoid'))
    model.add(Dropout(0.5))
    model.add(Dense(nb_classes, init='uniform'))
    model.add(Activation('softmax'))
    
    sgd = SGD(lr=0.1, decay=1e-6, momentum=0.9, nesterov=True)
    model.compile(loss='categorical_crossentropy',  optimizer=sgd)
    model.fit(X_train, y_train, batch_size=batch_size, nb_epoch=nb_epoch, show_accuracy=True, verbose=1, validation_data=(X_test, y_test))
    return model

def evaluate(model,X_test, Y_test):
    score = model.evaluate(X_test, Y_test, show_accuracy=True, verbose=0)
    return score




#




